"""
Flask-Was
-------------

🍾 Flask extension for JSON API
"""
from setuptools import setup, find_packages


setup(
    name="flask_was",
    version="0.1.0",
    packages=find_packages(),
    install_requires=["Flask"],
)
